@@ -2,7 +2,7 @@ package Test2::Event;
 use strict;
 use warnings;
 
-our $VERSION = '1.302129'; # TRIAL
+our $VERSION = '1.302131'; # TRIAL
 
 use Test2::Util::HashBase qw/trace -amnesty uuid -hubs/;
 use Test2::Util::ExternalMeta qw/meta get_meta set_meta delete_meta/;
@@ -90,6 +90,9 @@ sub common_facet_data {
     my %out;
 
     $out{about} = {package => ref($self) || undef};
+    if (my $uuid = $self->uuid) {
+        $out{about}->{uuid} = $uuid;
+    }
 
     if (my $trace = $self->trace) {
         $out{trace} = { %$trace };
@@ -118,10 +121,6 @@ sub facet_data {
     $out->{about}->{details}    = $self->summary    || undef;
     $out->{about}->{no_display} = $self->no_display || undef;
 
-    if (my $uuid = $self->uuid) {
-        $out->{about}->{uuid} = $uuid;
-    }
-
     # Might be undef, we want to preserve that
     my $terminate = $self->terminate;
     $out->{control} = {
